@@ -51,7 +51,7 @@ class KGameDialogConfig : public QWidget
 {
 	Q_OBJECT
 public:
-	KGameDialogConfig(QWidget* parent = 0);
+	explicit KGameDialogConfig(QWidget* parent = 0);
 	virtual ~KGameDialogConfig();
 
 	/**
@@ -139,7 +139,7 @@ class KGameDialogNetworkConfig : public KGameDialogConfig
 {
 	Q_OBJECT
 public:
-	KGameDialogNetworkConfig(QWidget* parent = 0);
+	explicit KGameDialogNetworkConfig(QWidget* parent = 0);
 	virtual ~KGameDialogNetworkConfig();
 
 
